@@ -4,16 +4,14 @@
 quirks_wayfire() {
 	WAYFIRE_LOCAL_CONFIG="${XDG_CONFIG_HOME}/wayfire.ini"
 	# detect disabled xwayland
-	if grep -qE '^[[:space:]]*xwayland[[:space:]]*=[[:space:]]*false' "${WAYFIRE_LOCAL_CONFIG}" 2>/dev/null
-	then
+	if grep -qE '^[[:space:]]*xwayland[[:space:]]*=[[:space:]]*false' "${WAYFIRE_LOCAL_CONFIG}" 2> /dev/null; then
 		XWAYLAND=false
 	else
 		XWAYLAND=true
 	fi
 
 	# append "wlroots" to XDG_CURRENT_DESKTOP if not already there
-	if [ "${__WM_DESKTOP_NAMES_EXCLUSIVE__}" != "true" ]
-	then
+	if [ "${__WM_DESKTOP_NAMES_EXCLUSIVE__}" != "true" ]; then
 		case "A:${XDG_CURRENT_DESKTOP}:Z" in
 		*:wlroots:*) true ;;
 		*) export XDG_CURRENT_DESKTOP="${XDG_CURRENT_DESKTOP}:wlroots" ;;
